@@ -49,8 +49,6 @@
 
 package com.openexchange.halo.pictures;
 
-import java.util.Arrays;
-import java.util.Collection;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
 import com.openexchange.exception.OXException;
@@ -81,9 +79,4 @@ public class PictureHaloActionFactory implements AJAXActionServiceFactory {
         return getPictureAction;
     }
 
-    @Override
-    public Collection<?> getSupportedServices() {
-        return Arrays.asList("get");
-    }
-
 }
